FunctionSpan

Struct FunctionSpan 

pub struct FunctionSpan {
    pub name: Spur,
    pub body_start: InstRef,
    pub decl: InstRef,
}
Stored representation of directive in the extra array. Layout: [name: u32, span_start: u32, span_len: u32, args_len: u32, args…] Variable size due to args. A span marking the boundaries of a function in the RIR.

This allows efficient per-function analysis by identifying which instructions belong to each function without scanning the entire instruction array.

Fields

name: Spur

Function name symbol

body_start: InstRef

Index of the first instruction of this function’s body. This is the first instruction generated for the function’s expressions/statements.

decl: InstRef

Index of the FnDecl instruction for this function. This is always the last instruction of the function.

Implementations

Source

impl FunctionSpan

pub fn new(name: Spur, body_start: InstRef, decl: InstRef) -> Self

Create a new function span.

pub fn instruction_count(&self) -> u32

Get the number of instructions in this function (including the FnDecl).