pub struct FunctionSpan {
pub name: Spur,
pub body_start: InstRef,
pub decl: InstRef,
}Expand description
Stored representation of directive in the extra array. Layout: [name: u32, span_start: u32, span_len: u32, args_len: u32, args…] Variable size due to args. A span marking the boundaries of a function in the RIR.
This allows efficient per-function analysis by identifying which instructions belong to each function without scanning the entire instruction array.
Fields
name: SpurFunction name symbol
body_start: InstRefIndex of the first instruction of this function’s body. This is the first instruction generated for the function’s expressions/statements.
decl: InstRefIndex of the FnDecl instruction for this function. This is always the last instruction of the function.
Implementations
Sourceimpl FunctionSpan
impl FunctionSpan